@@ -125,7 +125,7 @@ class VerifyToken:
         else:
             logging.error('计算组件未建立连接/依赖到认证中心，无法注册权限')
 
-    def permission_verify(self, center_name, permission_name) -> int:
+    def permission_verify(self, center_name, permission_name) -> dict:
         """
         验证权限，通过所属 中心/权限名称 获取当前用户的权限
           center_name = '用户管理'  # 当前视图函数所属 中心
@@ -152,12 +152,16 @@ class VerifyToken:
                 status=500,
             )
         permission_list = [0]
+        is_all_data = False
         user = self.user_db.find_docu_by_id(id=self.uid)  # 查询用户对应的角色数据
         role_name_list = user['role_name']  # 用户包含的所有角色名称
         for role_name in role_name_list:
             # 查询角色包含的权限集合，role_name + center_name + permission_name 不重复
-            roles = self.role_db.find_docu(find_dict={
-                                           'role_name': role_name, 'center_name': center_name, 'permission_name': permission_name}, many=False)
+            roles = self.role_db.find_docu(find_dict={'role_name': role_name,
+                                                      'center_name': center_name,
+                                                      'permission_name': permission_name
+                                                      },
+                                           many=False)
             if roles:
                 permission_list = roles[0]['permission_status']  # list类型
                 is_all_data = roles[0]['is_all_data']  # 是否开放全部数据
